# Third-Party Licenses and Attributions

This project (`syssimx`) is licensed under MIT (see `LICENSE`).

## Dependency licenses (high-level)

The project depends on external libraries with their own licenses. Typical key licenses in use:

- OpenSim: Apache-2.0
- fmpy: BSD-2-Clause
- NGSolve / Netgen: LGPL-2.1
